@@ -1,13 +1,18 @@
-# coding=utf-8
+from typing import Dict
 
-from __future__ import unicode_literals
 from .. import Provider as LoremProvider
 
 
 class Provider(LoremProvider):
-    """fr_FR word list is drawn from the French Education Ministry's website Eduscol.
-    The "Lexical frequency list" can be found here:
-    http://eduscol.education.fr/cid47915/liste-des-mots-classee-par-ordre-alphabetique.html"""
+    """Implement lorem provider for ``fr_FR`` locale.
+
+    Word list is drawn from the French Education Ministry's website Eduscol. The
+    "lexical frequency list" can be found in the source(s) below.
+
+    Sources:
+
+    - http://eduscol.education.fr/cid47915/liste-des-mots-classee-par-ordre-alphabetique.html
+    """
 
     word_list = (
         "à",
@@ -1473,3 +1478,5 @@ class Provider(LoremProvider):
         "y",
         "yeux",
     )
+
+    parts_of_speech: Dict[str, tuple] = {}
